
package lambdademo;

import java.util.LinkedList;

public class LambdaAvgExtraParallel {
    
    private static int loopCount = Constants.DEFAULT_LOOP_COUNT;
    
    /* 
     * Rube Goldberg way of caluclating identity of 'val',
     * assuming number is positive
     */
    private static double identity(double val) {
        double result = 0;
        for (int i=0; i < loopCount; i++) {
            result += Math.sqrt(Math.abs(Math.pow(val, 2)));    
        }
        return result / loopCount;
    }
    
    public static void main(String[] args) {    
        if (args.length != 0) {
            loopCount = Integer.valueOf(args[0]);
        }
        System.out.println("LambdaAvgExtraParallel: iterations = " + loopCount);
        
        long nanoStart = System.nanoTime();
        EmployeeFile empFile = new EmployeeFile() ;
        LinkedList<EmployeeRec> employeeList = empFile.loadEmployeeList();
        long nanoReadTime = System.nanoTime() - nanoStart;
        System.out.println("File read time in mS = " + nanoReadTime/1000000);
        
        long nanoStartProcessTime = System.nanoTime();
        
        double avgAge = employeeList.parallelStream()
                .filter(s -> s.getGender().equals("M"))
                .mapToDouble(s -> identity(s.getAge()))
                .average()
                .getAsDouble();
        
        long nanoProcessTime = System.nanoTime() - nanoStartProcessTime;
        
        System.out.println(String.format("Average Male Age = %.1f", avgAge));
        System.out.println("Processing Time in mS = " + nanoProcessTime/1000000);
    }
}
